#
# spec file for package python3-stevedore
#
# Copyright (c) 2017 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-stevedore
Version:        1.20.0
Release:        1.1
Summary:        Manage dynamic plugins for Python applications
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://git.openstack.org/cgit/openstack/stevedore
Source:         https://files.pythonhosted.org/packages/source/s/stevedore/stevedore-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python3-devel
BuildRequires:  python3-pbr
BuildRequires:  python3-setuptools
# Documentation requirements:
# BuildRequires:  python3-Sphinx
# Test requirements:
#BuildRequires:  python-mock
#BuildRequires:  python-nose
BuildArch:      noarch
Requires:       python3-pbr >= 1.6
Requires:       python3-six >= 1.9.0

%description
stevedore provides manager classes for implementing common patterns
for using dynamically loaded extensions in an effort to reduce
repetitive entry point management code.

%prep
%setup -q -n stevedore-%{version}

%build
python3 setup.py build
# (posophe) Documentation building fails for instance
# python3 setup.py build_sphinx

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
%fdupes -s %{buildroot}

#%%check
#nosetests

%files
%defattr(-,root,root,-)
%doc LICENSE README.rst
#%doc build/sphinx/html
%{python3_sitelib}/*

%changelog
* Thu Jan 26 2017 jengelh@inai.de
- Improve on description
* Fri Jan 20 2017 arun@gmx.de
- update to version 1.20.0:
  * extension: add entry_point_names method
  * extension: expose _find_entry_points as list_entry_points
  * Allow suppression of warnings from DriverManager
  * Show team and repo badges on README
  * Add Constraints support
* Wed Jan 18 2017 arun@gmx.de
- specfile:
  * update copyright year
- update to version 1.19.1:
  * Broken link at stevedore developer documentation
- changes from version 1.19.0:
  * Add Apache 2.0 license to source file
  * Updated from global requirements
  * Add reno for release notes management
  * Updated from global requirements
  * Remove reference to non-existing page
* Sat Nov 26 2016 arun@gmx.de
- update to version 1.18.0:
  * Updated from global requirements
  * Fix typos in exception.py
* Sun Sep 25 2016 arun@gmx.de
- update to version 1.17.1:
  * do not emit warnings for missing hooks
* Sun Aug  7 2016 arun@gmx.de
- update to version 1.17.0:
  * Remove discover from test-requirements
  * make error reporting for extension loading quieter
  * Add Python 3.5 classifier and venv
  * Replace assertEquals() with assertEqual()
* Wed Jul 13 2016 arun@gmx.de
- update to version 1.16.0:
  * Fix NamedExtensionManager fails when loading failing extension in
    order
  * Remove irrelated output item
  * Fix broken link about setuptools entry points
  * NamedExtensionManager: call a callback when some names cannot be
    found
  * Updated from global requirements
* Fri Jun 24 2016 arun@gmx.de
- update to version 1.15.0:
  * Updated from global requirements
* Sat May 28 2016 arun@gmx.de
- update to version 1.14.0:
  * Trivial: ignore openstack/common in flake8 exclude list
- changes from version 1.13.0:
  * dont claim copyright for future years
* Thu May 19 2016 toddrme2178@gmail.com
- Comment out documentation requirements since documentation is
  not currently working.
* Sun May  8 2016 arun@gmx.de
- specfile:
  * changed to https for source url
  * updated source url to files.pythonhosted.org
* Sat Feb 27 2016 arun@gmx.de
- update to version 1.12.0:
  * Add a reference to entry_point_inspector
* Fri Feb 12 2016 arun@gmx.de
- specfile:
  * update copyright year
  * removed argparse dependency
- update to version 1.11.0:
  * Updated from global requirements
  * Trival:Remove unused logging import
  * Remove work around for NullHandler
  * remove unnecessary dependency on argparse
* Mon Dec 14 2015 arun@gmx.de
- update to version 1.10.0:
  * Use Stevedore exceptions for finding extensions
  * Clean up Python 2.6 related stuff
  * Updated from global requirements
  * Remove Python 2.6 classifier
  * cleanup tox.ini
* Sat Oct 17 2015 arun@gmx.de
- update to version 1.9.0:
  * Updated from global requirements
  * docs - Set pbr 'warnerrors' option for doc build
  * Add clarifying language to description of scanning for plugins
  * clean up default tox environment list
  * Show how to add a plugin in a separate package
  * replace the hard-coded history list with an auto-generated one
  * Fix spelling typo for maunal
  * Examples typo fix
* Tue Oct  6 2015 aloisio@gmx.com
- Added missing Requires.
- Added fdupes
* Sun Oct  4 2015 arun@gmx.de
- update to version 1.8.0:
  * Updated from global requirements
- changes from version 1.7.0:
  * Updated from global requirements
  * Titlecase looks nicer sometimes in detailed mode
  * Update homepage to openstack hosted docs page
* Sun Jul 19 2015 arun@gmx.de
- update to version 1.6.0:
  * Document the signature for check_func
  * Updated from global requirements
  * Switch badges from 'pypip.in' to 'shields.io'
  * Remove unnecessary openstack-common.conf
* Fri Jun  5 2015 arun@gmx.de
- update to version 1.5.0:
  * Removed non-free color profile from .jpg
  * RemovedMerge "Add sphinx integration"
  * Updated from global requirements
  * Merge "Fix Python versions supported"
  * Fix Python versions supported
  * Merge "Remove run_cross_tests.sh"
  * Merge "re-raise exception with full traceback"
  * Merge "Add pypi download + version badges"
  * Remove run_cross_tests.sh
  * fix author contact details
* Sat Apr 25 2015 arun@gmx.de
- update to version 1.4.0:
  * Uncap library requirements for liberty
  * Updated from global requirements
* Wed Mar 11 2015 arun@gmx.de
- update to version 1.3.0:
  * clean up default environments run by tox
  * ignore .testrepository directory created by testr
  * Fix test for finding multiple drivers
  * Updated from global requirements
* Sun Jan 18 2015 arun@gmx.de
- specfile:
  * update copyright year
  * update url
  * added pbr as build requirement
- update to version 1.2.0:
  * Use pkg_resources resolve() and require() instead of load()
  * Fix the README.rst file format for pypi
  * Workflow documentation is now in infra-manual
  * Implement a __contains__ override for extension manager
  * Update link to docs in README
- changes from version 1.1.0:
  * Add pbr to dependency list
  * Updated from global requirements
  * Add more detail to the README
  * Migrate tox to use testr
  * Update repository location in docs
- changes from version 1.0.0:
  * Build universal wheels
  * Work toward Python 3.4 support and testing
  * warn against sorting requirements
  * Updated from global requirements
  * Fix incorrect image reference in documentation
  * Fix requirement handling in tox
  * Updated from global requirements
  * use six.add_metaclass
  * Updated from global requirements
  * driver: raise by default on import failure
  * Add doc requirements to venv environ
  * Import run_cross_tests.sh from oslo-incubator
  * fix link to entry point docs
- changes from version 0.15:
  * Only log error when no load handler is set
  * Update readme with links to bug tracker and source
  * Update .gitreview after moving the repository
- changes from version 0.14.1:
  * Fix the test manager implementation
- changes from version 0.14:
  * Provide an option to control requirements checking when loading
    plugins, and disable it by default. This removes protection
    against loading the wrong version of a plugin, or that plugin's
    dependencies.
- changes from version 0.13:
  * Deprecate "TestExtensionManager" and replace with
    "make_test_instance()" class method to provide test classes that
    behave more like the production class, while still allowing the
    extensions to be injected for testing. (contributed by drocco-007)
  * Include a work-around to avoid a cpython bug with atexit
    (#15881). (contributed by philiptzou)
  * Update documentation to refer to setuptools instead of
    distribute. (contributed by westurner)
  * Add pypy to the list of default test configurations.
- changes from version 0.12:
  * Fixes an exception when reporting on an error where multiple drivers
    have the same name (:issue:`25`, solution provided by clayg).
  * Switch packaging to use pbr_.
  * Add "map_method()" API to controllers.
* Sat Oct 12 2013 p.drouand@gmail.com
- Initial python3 support
* Mon Sep  2 2013 dmueller@suse.com
- update to 0.11:
  * Fixes logging configuration under Python 2.6 with a NullHandler
* Thu Jul 11 2013 dmueller@suse.com
- update to 0.10:
  - Adds ``propagate_map_exceptions`` parameter to all of the extension
  managers which specifies whether exceptions are propagated up
  through the map call or logged and then ignored. The default is to
  preserve the current behavior of logging and ignoring exceptions.
- remove python-2.6.x.diff
* Fri Jun 21 2013 dmueller@suse.com
- add python-2.6.x.diff:
  * fix build on python 2.6
* Mon Jun 17 2013 speilicke@suse.com
- Update to version 0.9.1:
  + Add name_order parameter to NamedExtensionManager to coerce map() into
    processing the extensions in the order they are named when the manager is
    created, instead of the random order they may have been loaded.
  + Change the NamedDispatchExtensionManager to ignore missing extensions
    (issue 14).
  + Add __getitem__ to ExtensionManager for looking up individual plugins by
    name (issue 15).
  + Start working on the tutorial, Using Stevedore in Your Application.
- Drop semantic versioning hack
- Build HTML documentation
* Wed May 29 2013 dmueller@suse.com
- add compatibility provides of 0.8.0 version
  * needed for other packages that generate the version from
  * PyPi (where this is fetched when fetching 0.8.0)
* Sat Jan  5 2013 alexandre@exatati.com.br
- Update to 0.8:
  - Ignore AssertionError exceptions generated when plugins are
    loaded.
  - Update :class:`~stevedore.named.NamedExtensionManager` to check
    the name of a plugin before loading its code to avoid importing
    anything we are not going to use.
* Tue Dec  4 2012 alexandre@exatati.com.br
- Update to 0.7.2:
  - Fix logging support for Python 2.6.
- Aditional changes from 0.7.1:
  - Fix an issue with logging configuration.
- Aditional changes from 0.7:
  - Add memoization to the entrypoint scanning code in
    stevedore.extension.ExtensionManager to avoid performance issues
    in situations where lots of managers are instantiated with the
    same namespace argument.
* Wed Nov 21 2012 saschpe@suse.de
- Install LICENSE, README.rst and HTML documentation
* Mon Oct 29 2012 alexandre@exatati.com.br
- Update to 0.6:
  - Change the stevedore.enabled.EnabledExtensionManager to load
    the extension before calling the check function so the plugin
    can be asked if it should be enabled.
- Aditional changes from 0.5:
  - Add stevedore.tests.manager.TestExtensionManager for writing
    tests for classes that use extension managers.
* Sun Sep 16 2012 alexandre@exatati.com.br
- Update to 0.4:
  - Removed the name argument to plugin constructors.
  - Added driver property to stevedore.driver.DriverManager.
* Sun Aug 19 2012 alexandre@exatati.com.br
- Initial package (0.3) for openSUSE.
